function disegna_letto_capillare7(G,p,v)
% disegna_letto_capillare7(G,p,v), disegna le pressioni e le vel medie
% del letto capillare con 7 capillari
% Input: G = matrice del grafo
%        p = vettore delle pressioni nei nodi
%        v = matrice delle velocita` medie nei capillari
n=length(G);
m=sqrt(n-2);

% costruisco i nodi della rete
sa=3/5;ca=4/5;
xy=[0,0; % nodo 0
    0.3, 0; % nodo 1
    0.3+0.3*ca, 0.3*sa; % nodo 2 
    0.3+0.4*sa, -0.4*ca; % nodo 3
    0.3+2*0.3*ca, 0; % nodo 4;
    0.3+2*0.3*ca+0.3,0]; % nodo 5

x=xy(1:n,1); y=xy(1:n,2);
x=x+abs(min(x)); y=y+abs(min(y));
xy=[x,y];    

%
np=32;
colore=zeros(np,3);
v2=linspace(0,1,np);
colore(1:np,1)=v2; 
v1=linspace(1,0,np);
colore(:,3)=1;
colore(1:np,3)=v1;


% disegno la pressione
figure(1); clf
for i=1:n
for j=i+1:n
    if G(i,j)~=0
x1=[x(i),(x(i)+x(j))/2,x(j)];
y1=[y(i),(y(i)+y(j))/2,y(j)];
p1=[p(i),(p(i)+p(j))/2,p(j)];
patch([x1 nan],[y1 nan] ,[p1,nan], [p1,nan],...
   'EdgeColor','interp','FaceColor','none','Linewidth',2);
hold on
    end
end
end
grid on
 
colormap(colore)
view([38,16])
axis([min(x),max(x),min(y),max(y),min(p),max(p)]) 
daspect([xy(end,1),xy(end,1),40]) 
t1=text(1.138,0.189,min(p)-1.5,'venula');
t2=text(-0.18, 0.35,max(p)+2,'arteriola');
zlabel('pressione (mmHg)','Fontsize',16)
colorbar

% disegno le velocita`
figure(2); clf

cmap=colormap(hsv(32));
vmin=100;
for i=1:n
    for j=1:n
        if v(i,j)>0
vmin=min([vmin,v(i,j)]); 
        end
    end
end
vcolore=zeros(size(v));
vmax=max(max(v));
for i=1:n
    for j=1:n
        if v(i,j)>0
vcolore(i,j)=round(1+(size(cmap,1)-1)*(v (i,j)- vmin)/(vmax-vmin));
        end
    end
end

% 
i=1;
for j=i+1:n
        if G(i,j)~=0
patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
hold on
        end
end

for i1=1:m
    for i2=1:m
    i=(i2-1)*m+i1+1;
        for j=i+1:n
        if G(i,j)~=0
 patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
       end
        end
    end
end
colormap(hsv(32))
colorbar
view([25,44])
daspect([xy(end,1),xy(end,1),2]) 
grid on
zlabel('vel. medie (mm/s)','Fontsize',16)
t1=text(1.065 ,0.2416,v(1,2)+0.1,'venula');
t2=text(-0.08, 0.3, v(end-1,end)+0.1,'arteriola');


axis([min(x),max(x),min(y),max(y),0,max(max(v))]) 
